@@ -28,7 +28,7 @@ def main( ) :
     """
     name_package = 'cressp'
     dir_remote = 'https://github.com/ahs2202/cressp2/raw/main/cressp/' # remote directory from which datafiles will be downloaded
-    dir_folder_cressp = f'{pkg_resources.resource_filename( name_package, '' )}/' # directory of the current installed package
+    dir_folder_cressp = f"{pkg_resources.resource_filename( name_package, '' )}/" # directory of the current installed package
     
     
     """
@@ -88,9 +88,9 @@ def main( ) :
             print( "exiting since query proteins other than default human proteins were given, the default HMM profile database cannot be used" )
             sys.exit( )
     # get absolute paths for file arguments        
-    dir_file_target_protein = os.path.abspath( args.dir_file_target_protein )
-    dir_file_query_protein = os.path.abspath( args.dir_file_query_protein )
-    dir_file_query_hmmdb = os.path.abspath( args.dir_file_query_hmmdb )
+    dir_file_target_protein = os.path.abspath( dir_file_target_protein )
+    dir_file_query_protein = os.path.abspath( dir_file_query_protein )
+    dir_file_query_hmmdb = os.path.abspath( dir_file_query_hmmdb )
     
     # handle default setting for the output folder
     if dir_folder_output == 'default' :
